slepc-3.18.0 2022-10-01
Report Typos and Errors

# BVDuplicateResize

Creates a new basis vector object of the same type and dimensions as an existing one, but with possibly different number of columns.

### Synopsis

    #include "slepcbv.h"
    PetscErrorCode BVDuplicateResize(BV V,PetscInt m,BV *W)

Collective on V

### Input Parameters

| V | - basis vectors context
| m | - the new number of columns

### Output Parameter

| W | - location to put the new BV

### Note

This is equivalent of a call to BVDuplicate() followed by BVResize(). The contents of V are not copied to W.

### See Also

BVDuplicate(), BVResize()

### Level

intermediate

### Location

src/sys/classes/bv/interface/bvbasic.c
Index of all BV routines
Table of Contents for all manual pages
Index of all manual pages